'use client';


import { useEffect, useState } from 'react';
import React from "react";
import {
  PublicKey,
  Transaction,
  sendAndConfirmTransaction,
  Connection,
  SystemProgram,
} from "@solana/web3.js";
import axios from 'axios';
import { usePrivy } from '@privy-io/react-auth';
import { useSolanaWallets } from '@privy-io/react-auth/solana';
import { createClient } from '@supabase/supabase-js';
import {
  getAssociatedTokenAddress,
  createTransferInstruction,
  TOKEN_PROGRAM_ID,
  ASSOCIATED_TOKEN_PROGRAM_ID,
  createAssociatedTokenAccountInstruction,
} from "@solana/spl-token";

interface GpuPaymentModalProps {
  isOpen: boolean;
  onClose: () => void;
  gpu: {
    id: string;
    title: string;
    price_usd: number;
    price_per_hour: string;
  };
}

interface CustomToken {
  address: string;
  id: number;
  project_name: string;
}

const SOLANA_RPC = process.env.NEXT_PUBLIC_SOLANA_RPC!;
const BUSINESS_WALLET = process.env.NEXT_PUBLIC_BUSINESS_WALLET!;
const EMAIL_API_URL = process.env.NEXT_PUBLIC_EMAIL_API_URL!;
const CUSTOM_TOKEN_API_URL = "https://catools.dev3vds1.link/get/vertex";

const USDC_MINT = new PublicKey("EPjFWdd5AufqSSqeM2qN1xzybapC8G4wEGGkZwyTDt1v");

const CornerEdge = ({ position }: { position: 'left-top' | 'right-top' | 'left-bottom' | 'right-bottom' }) => {
  const paths = {
    'left-top': (
      <>
        <path d="M1 0V4.5" stroke="#0CE77E" strokeWidth="1" />
        <path d="M5.5 0.5L1 0.5" stroke="#0CE77E" strokeWidth="1" />
      </>
    ),
    'right-top': (
      <>
        <path d="M5 0V4.5" stroke="#0CE77E" strokeWidth="1" />
        <path d="M0.5 0.5L5 0.5" stroke="#0CE77E" strokeWidth="1" />
      </>
    ),
    'left-bottom': (
      <>
        <path d="M1 4.5V0" stroke="#0CE77E" strokeWidth="1" />
        <path d="M5.5 4L1 4" stroke="#0CE77E" strokeWidth="1" />
      </>
    ),
    'right-bottom': (
      <>
        <path d="M5 4.5V0" stroke="#0CE77E" strokeWidth="1" />
        <path d="M0.5 4L5 4" stroke="#0CE77E" strokeWidth="1" />
      </>
    )
  };

  return (
    <svg
      width="6"
      height="5"
      viewBox="0 0 6 5"
      fill="none"
      xmlns="http://www.w3.org/2000/svg"
      className={`absolute ${position.includes('left') ? 'left-0' : 'right-0'} ${position.includes('top') ? 'top-0' : 'bottom-0'}`}
    >
      {paths[position]}
    </svg>
  );
};

// Red corner edges for error UI
const RedCornerEdge = ({ position }: { position: 'left-top' | 'right-top' | 'left-bottom' | 'right-bottom' }) => {
  const paths = {
    'left-top': (
      <>
        <path d="M1 0V4.5" stroke="#F62727" strokeWidth="1" />
        <path d="M5.5 0.5L1 0.5" stroke="#F62727" strokeWidth="1" />
      </>
    ),
    'right-top': (
      <>
        <path d="M5 0V4.5" stroke="#F62727" strokeWidth="1" />
        <path d="M0.5 0.5L5 0.5" stroke="#F62727" strokeWidth="1" />
      </>
    ),
    'left-bottom': (
      <>
        <path d="M1 4.5V0" stroke="#F62727" strokeWidth="1" />
        <path d="M5.5 4L1 4" stroke="#F62727" strokeWidth="1" />
      </>
    ),
    'right-bottom': (
      <>
        <path d="M5 4.5V0" stroke="#F62727" strokeWidth="1" />
        <path d="M0.5 4L5 4" stroke="#F62727" strokeWidth="1" />
      </>
    )
  };

  return (
    <svg
      width="6"
      height="5"
      viewBox="0 0 6 5"
      fill="none"
      xmlns="http://www.w3.org/2000/svg"
      className={`absolute ${position.includes('left') ? 'left-0' : 'right-0'} ${position.includes('top') ? 'top-0' : 'bottom-0'}`}
    >
      {paths[position]}
    </svg>
  );
};

const SuccessIcon = () => {
  return (
    <div className="relative h-[54px] w-[54px]">
      <div className="absolute top-0 left-0 bg-emerald-500 rounded-xl h-[54px] w-[54px]" />
      <svg
        width="39"
        height="38"
        viewBox="0 0 39 38"
        fill="none"
        xmlns="http://www.w3.org/2000/svg"
        className="absolute top-2 left-2"
        aria-hidden="true"
      >
        <path
          d="M32.1663 9.5L14.7497 26.9167L6.83301 19"
          stroke="black"
          strokeWidth="3.16667"
          strokeLinecap="round"
          strokeLinejoin="round"
        />
      </svg>
    </div>
  );
};

const ErrorIcon = () => {
  return (
    <div className="relative h-[54px] w-[54px]">
      <div className="absolute top-0 left-0 bg-red-600 rounded-xl h-[54px] w-[54px]" />
      <svg
        width="38"
        height="38"
        viewBox="0 0 38 38"
        fill="none"
        xmlns="http://www.w3.org/2000/svg"
        className="absolute top-2 left-2"
        aria-hidden="true"
      >
        <path
          d="M29 9.5L10 28.5M10 9.5L29 28.5"
          stroke="black"
          strokeWidth="3.16667"
          strokeLinecap="round"
          strokeLinejoin="round"
        />
      </svg>
    </div>
  );
};


const ErrorBox = () => {
  return (
    <div className="relative w-full max-w-[357px] h-[60px]">
      <div className="absolute inset-0 bg-[#F62727] bg-opacity-10" />
      <div className="absolute inset-[1px] border border-white border-opacity-5" />
      <div className="absolute flex justify-between items-center px-5 w-full h-full">
        <span className="font-mono text-[18px] font-medium text-white">
          Error
        </span>
        <span className="font-mono text-[18px] font-medium text-[#F62727]">
          404 (Payment Error)
        </span>
      </div>
      <RedCornerEdge position="left-top" />
      <RedCornerEdge position="right-top" />
      <RedCornerEdge position="left-bottom" />
      <RedCornerEdge position="right-bottom" />
    </div>
  );
};

interface OrderIdBoxProps {
  orderId: string;
}

const OrderIdBox = ({ orderId }: OrderIdBoxProps) => {
  return (
    <div className="relative w-full max-w-[357px] h-[60px]">
      <div className="absolute inset-0 bg-[#0CE77E] bg-opacity-10" />
      <div className="absolute inset-[1px] border border-white border-opacity-5" />
      <div className="absolute flex justify-between items-center px-5 w-full h-full">
        <span className="font-mono text-[18px] font-medium text-white">
          Order ID
        </span>
        <span className="font-mono text-[18px] font-medium text-[#0CE77E]">
          {orderId}
        </span>
      </div>
      <CornerEdge position="left-top" />
      <CornerEdge position="right-top" />
      <CornerEdge position="left-bottom" />
      <CornerEdge position="right-bottom" />
    </div>
  );
};

export const GpuPaymentModal = ({ isOpen, onClose, gpu }: GpuPaymentModalProps) => {
  const { user, connectWallet } = usePrivy();
  const { wallets: privyWallets } = useSolanaWallets();

  const [solPrice, setSolPrice] = useState<number | null>(null);
  const [customToken, setCustomToken] = useState<CustomToken | null>(null);
  const [customTokenPrice, setCustomTokenPrice] = useState<number | null>(null);
  const [customTokenName, setCustomTokenName] = useState<string>('VERTEX');
  const [emailInput, setEmailInput] = useState('');
  const [loading, setLoading] = useState(false);
  const [errorMsg, setErrorMsg] = useState<string | null>(null);
  const [successMsg, setSuccessMsg] = useState<string | null>(null);
  const [paymentSuccess, setPaymentSuccess] = useState(false);
  const [paymentFailure, setPaymentFailure] = useState(false);
  const [orderId, setOrderId] = useState<string>('');

  const connection = new Connection(SOLANA_RPC);
  const userEmail = user?.email?.address || emailInput || null;
  const isValidEmail = (email: string) => /^[^\s@]+@[^\s@]+\.[^\s@]+$/.test(email);
  const [emailTouched, setEmailTouched] = useState(false);
  const [selectedToken, setSelectedToken] = useState<'SOL' | 'USDC' | 'VERTEX'>('SOL');

  const supabase = createClient(
    process.env.NEXT_PUBLIC_SUPABASE_URL!,
    process.env.NEXT_PUBLIC_SUPABASE_ANON_KEY!
  );

  // Calculate token amounts based on selected token
  const [currentTokenAmount, setCurrentTokenAmount] = useState<string>('');

  useEffect(() => {
    const fetchSolPrice = async () => {
      try {
        const { data } = await axios.get(
          'https://api.coingecko.com/api/v3/simple/price?ids=solana&vs_currencies=usd'
        );
        setSolPrice(data.solana.usd);
      } catch (error) {
        console.error("Failed to fetch SOL price:", error);
        setErrorMsg('Failed to fetch SOL price.');
      }
    };

    const fetchCustomToken = async () => {
      try {
        const { data } = await axios.get(CUSTOM_TOKEN_API_URL);
        if (data && Array.isArray(data) && data.length > 0) {
          setCustomToken(data[0]);
          
          // Fetch the actual token price from CoinGecko or Jupiter Aggregator
          await fetchTokenPrice(data[0].address);
          
          // Try to get token metadata using the address
          fetchTokenMetadata(data[0].address);
        }
      } catch (error) {
        console.error("Failed to fetch custom token:", error);
      }
    };

    const fetchTokenPrice = async (tokenAddress: string) => {
      try {
        // First attempt: Try using CoinGecko if the token is listed there by contract address
        // Convert Solana address to CoinGecko platform format
        const platformId = 'solana';
        const contractAddress = tokenAddress;
        
        try {
          const coinGeckoUrl = `https://api.coingecko.com/api/v3/simple/token_price/${platformId}?contract_addresses=${contractAddress}&vs_currencies=usd`;
          const response = await axios.get(coinGeckoUrl);
          
          // Check if we got a valid price
          if (response.data && response.data[contractAddress.toLowerCase()] && response.data[contractAddress.toLowerCase()].usd) {
            setCustomTokenPrice(response.data[contractAddress.toLowerCase()].usd);
            return;
          }
        } catch (cgError) {
          console.log("CoinGecko lookup failed, trying alternative source");
        }
        
        // Second attempt: Try using Jupiter Aggregator API for Solana tokens
        try {
          // Jupiter provides price data for most Solana tokens
          const jupiterUrl = `https://lite-api.jup.ag/price/v2?ids=${tokenAddress}`;
          const jupResponse = await axios.get(jupiterUrl);
          
          if (jupResponse.data && 
              jupResponse.data.data && 
              jupResponse.data.data[tokenAddress] && 
              jupResponse.data.data[tokenAddress].price) {
            setCustomTokenPrice(jupResponse.data.data[tokenAddress].price);
            return;
          }
        } catch (jupError) {
          console.log("Jupiter API lookup failed, trying another alternative");
        }
        
        // Third attempt: Try using Raydium API (another Solana DEX)
        try {
          const raydiumUrl = `https://api.raydium.io/v2/main/price?tokens=${tokenAddress}`;
          const raydiumResponse = await axios.get(raydiumUrl);
          
          if (raydiumResponse.data && raydiumResponse.data[tokenAddress]) {
            setCustomTokenPrice(raydiumResponse.data[tokenAddress]);
            return;
          }
        } catch (raydiumError) {
          console.log("Raydium API lookup failed");
        }
        
        // Fallback: If all API calls fail, use a fallback price or calculate from an existing pool
        console.warn("Could not fetch price from any API, using fallback price");
        setCustomTokenPrice(0.5); // Fallback price as last resort
      } catch (error) {
        console.error("Failed to fetch token price:", error);
        // Default price as absolute fallback
        setCustomTokenPrice(0.5);
      }
    };

    const fetchTokenMetadata = async (address: string) => {
      try {
        // First try to get metadata from Solana token registry
        const tokenRegistryUrl = `https://cdn.jsdelivr.net/gh/solana-labs/token-list@main/src/tokens/solana.tokenlist.json`;
        const registryResponse = await axios.get(tokenRegistryUrl);
        const tokenList = registryResponse.data.tokens;
        
        // Find token in the registry by address
        const tokenInfo = tokenList.find((token: any) => token.address === address);
        
        if (tokenInfo) {
          // Use token info from the registry
          setCustomTokenName(tokenInfo.symbol.toUpperCase());
          return;
        }
        
        // If not found in registry, try to get on-chain metadata
        const tokenPublicKey = new PublicKey(address);
        const connection = new Connection(SOLANA_RPC);
        
        // Attempt to get token account info
        const tokenMint = await connection.getTokenSupply(tokenPublicKey);
        
        if (tokenMint) {
          // If we can't get a name from on-chain data, use project_name from our API
          // or fall back to default name
          if (customToken?.project_name) {
            setCustomTokenName(customToken.project_name.toUpperCase());
          } else {
            // If all else fails, use the default name
            setCustomTokenName('VERTEX');
          }
          return;
        }
    
        // If we couldn't get metadata, use the default name
        setCustomTokenName('VERTEX');
      } catch (error) {
        console.error("Failed to fetch token metadata:", error);
        // Default to VERTEX if we can't get the name
        setCustomTokenName('VERTEX');
      }
    };

    if (isOpen) {
      fetchSolPrice();
      fetchCustomToken();
      setErrorMsg(null);
      setSuccessMsg(null);
      setPaymentSuccess(false);
      setPaymentFailure(false);
    }
  }, [isOpen, customToken?.project_name]);

  // Update token amount when price or selected token changes
  useEffect(() => {
    updateTokenAmount();
  }, [selectedToken, solPrice, customTokenPrice, gpu.price_usd]);

  const updateTokenAmount = () => {
    if (selectedToken === 'SOL' && solPrice) {
      const amount = (gpu.price_usd / solPrice).toFixed(6);
      setCurrentTokenAmount(amount);
    } else if (selectedToken === 'USDC') {
      // USDC is a stablecoin, so 1 USDC ≈ 1 USD
      setCurrentTokenAmount(gpu.price_usd.toFixed(2));
    } else if (selectedToken === 'VERTEX' && customTokenPrice) {
      const amount = (gpu.price_usd / customTokenPrice).toFixed(2);
      setCurrentTokenAmount(amount);
    }
  };

  const handlePayment = async () => {
    setLoading(true);
    setErrorMsg(null);
    setSuccessMsg(null);

    let priceUsd = selectedToken === "VERTEX" ? gpu.price_usd * 0.9 : gpu.price_usd;
  
    try {
      if (!userEmail || !isValidEmail(userEmail)) {
        throw new Error("Please enter a valid email address for your receipt.");
      }
  
      const solWallet = privyWallets[0];
      if (!solWallet?.address || !solWallet.signTransaction) {
        throw new Error("No connected Solana wallet found or wallet can't sign.");
      }
  
      // Define the correct program IDs
      const TOKEN_PROGRAM_ID = new PublicKey("TokenkegQfeZyiNwAJbNbGKPFXCWuBvf9Ss623VQ5DA");
      const ASSOCIATED_TOKEN_PROGRAM_ID = new PublicKey("ATokenGPvbdGVxr1b2hvZbsiqW5xWH25efTNsLJA8knL");
  
      const fromPubKey = new PublicKey(solWallet.address);
      const toPubKey = new PublicKey(BUSINESS_WALLET);
      const transaction = new Transaction();
      let txId = "";
      let tokenUsed = selectedToken;
      let amountDisplay = "";
  
      if (selectedToken === "SOL") {
        // SOL Payment Logic (unchanged)
        const { data } = await axios.get(
          "https://api.coingecko.com/api/v3/simple/price?ids=solana&vs_currencies=usd"
        );
        const solPrice = data.solana.usd;
        const solAmount = (gpu.price_usd / solPrice).toFixed(6);
        amountDisplay = `${solAmount} SOL`;
  
        transaction.add(
          SystemProgram.transfer({
            fromPubkey: fromPubKey,
            toPubkey: toPubKey,
            lamports: Math.floor(parseFloat(solAmount) * 1e9),
          })
        );
      } else {
        // Token Payment Logic
        const selectedMint = selectedToken === "USDC" 
          ? USDC_MINT 
          : new PublicKey(customToken?.address || "");
        
        const tokenDecimals = 6;
  
        let tokenPrice = 1;
        if (selectedToken === "VERTEX") {
          tokenPrice = customTokenPrice || 0.5;
        }
  
        const priceUsd = selectedToken === "VERTEX" ? gpu.price_usd * 0.9 : gpu.price_usd;
        const tokenAmount = (priceUsd / tokenPrice).toFixed(tokenDecimals);
        amountDisplay = `${tokenAmount} ${selectedToken}`;
  
        // Get or create token accounts using the correct method
        const fromTokenAccount = await getAssociatedTokenAddress(
          selectedMint,
          fromPubKey,
          false,
          TOKEN_PROGRAM_ID,
          ASSOCIATED_TOKEN_PROGRAM_ID
        );
        
        const toTokenAccount = await getAssociatedTokenAddress(
          selectedMint,
          toPubKey,
          false,
          TOKEN_PROGRAM_ID,
          ASSOCIATED_TOKEN_PROGRAM_ID
        );
  
        // Check if destination token account exists
        const toTokenAccountInfo = await connection.getAccountInfo(toTokenAccount);
        
        if (!toTokenAccountInfo) {
          // Create associated token account with explicit program IDs
          transaction.add(
            createAssociatedTokenAccountInstruction(
              fromPubKey,
              toTokenAccount,
              toPubKey,
              selectedMint,
              TOKEN_PROGRAM_ID,
              ASSOCIATED_TOKEN_PROGRAM_ID
            )
          );
        }
  
        // Add token transfer instruction with explicit program ID
        transaction.add(
          createTransferInstruction(
            fromTokenAccount,
            toTokenAccount,
            fromPubKey,
            BigInt(Math.floor(parseFloat(tokenAmount) * Math.pow(10, tokenDecimals))),
            [],
            TOKEN_PROGRAM_ID
          )
        );
      }
  
      // Set transaction properties (unchanged)
      transaction.feePayer = fromPubKey;
      const { blockhash } = await connection.getLatestBlockhash();
      transaction.recentBlockhash = blockhash;
  
      // Sign and send (unchanged)
      const signedTx = await solWallet.signTransaction(transaction);
      txId = await connection.sendRawTransaction(signedTx.serialize());
      await connection.confirmTransaction(txId, "confirmed");
  
      // Process order completion (unchanged)
      await axios.post(EMAIL_API_URL, {
        email: userEmail,
        product: gpu.title,
        price_hour: gpu.price_per_hour,
        price: priceUsd.toFixed(2)
      });
  
      const generatedOrderId = `${Math.floor(Math.random() * 900) + 100}-${Math.floor(Math.random() * 900) + 100}-${Math.floor(Math.random() * 900) + 100}`;
      setOrderId(generatedOrderId);
  
      const { error } = await supabase.from("orders").insert([
        {
          gpu: `${gpu.id} ${gpu.title}`,
          user_email: userEmail,
          amount_usd: priceUsd,
          token_used: tokenUsed,
          token_amount: amountDisplay,
          token_tx_signature: txId,
          status: "success",
          order_id: generatedOrderId,
        },
      ]);
  
      if (error) throw new Error(`Failed to save order: ${error.message}`);
      setSuccessMsg(`Payment successful! Transaction ID: ${txId}`);
      setPaymentSuccess(true);
    } catch (err: any) {
      console.error("Payment error:", err);
      setErrorMsg(err.message || "Payment failed.");
      setPaymentFailure(true);
      
      // Log the failed attempt in Supabase
      const failedOrderId = `FAIL-${Math.floor(Math.random() * 900) + 100}-${Math.floor(Math.random() * 900) + 100}`;
      await supabase.from("orders").insert([
        {
          gpu: `${gpu.id} ${gpu.title}`,
          user_email: userEmail,
          amount_usd: priceUsd,
          token_used: selectedToken,
          status: "failed",
          error_message: err.message || "Unknown error",
          order_id: failedOrderId,
        },
      ]);
    } finally {
      setLoading(false);
    }
  };

  const handleRetry = () => {
    // Reset failure state and error message
    setPaymentFailure(false);
    setErrorMsg(null);
    // Don't reset other form values so user doesn't have to start over
  };

  if (!isOpen) return null;
  const displayPrice = selectedToken === 'VERTEX'
    ? (gpu.price_usd * 0.9).toFixed(2)
    : gpu.price_usd.toFixed(2);


  // Show failure screen if payment failed
  if (paymentFailure) {
    return (
      <div className="fixed inset-0 z-50 flex items-center justify-center bg-black/80">
        <div className="relative flex flex-col gap-8 items-center p-6 bg-[#0E1618] border border-white border-opacity-10 w-full max-w-lg mx-4">
          <RedCornerEdge position="left-top" />
          <RedCornerEdge position="right-top" />
          <RedCornerEdge position="left-bottom" />
          <RedCornerEdge position="right-bottom" />
          
          <ErrorIcon />
          
          <div className="flex flex-col gap-1.5 items-center">
            <h1 className="text-2xl text-center text-white">
              PURCHASE FAILED
            </h1>
            <p className="text-lg text-center text-white opacity-50">
              Your purchase didn't go through
            </p>
          </div>
          
          <ErrorBox />
          
          <div className="flex gap-4">
            <button
              onClick={handleRetry}
              className="relative w-[157px] h-[51px]"
            >
              <div className="absolute inset-0 bg-[#F62727] bg-opacity-25" />
              <div className="absolute inset-[1px] border border-white border-opacity-5" />
              <span className="absolute inset-0 flex items-center justify-center font-mono text-[17.85px] font-medium text-[#F62727]">
                RETRY
              </span>
              <RedCornerEdge position="left-top" />
              <RedCornerEdge position="right-top" />
              <RedCornerEdge position="left-bottom" />
              <RedCornerEdge position="right-bottom" />
            </button>
            
            <button
              onClick={onClose}
              className="relative w-[157px] h-[51px]"
            >
              <div className="absolute inset-0 bg-[#333333]" />
              <div className="absolute inset-[1px] border border-white border-opacity-5" />
              <span className="absolute inset-0 flex items-center justify-center font-mono text-[17.85px] font-medium text-white">
                CLOSE
              </span>
              <CornerEdge position="left-top" />
              <CornerEdge position="right-top" />
              <CornerEdge position="left-bottom" />
              <CornerEdge position="right-bottom" />
            </button>
          </div>
        </div>
      </div>
    );
  }

  // Show success screen if payment was successful
  if (paymentSuccess) {
    return (
      <div className="fixed inset-0 z-50 flex items-center justify-center bg-black/80">
        <div className="relative flex flex-col gap-8 items-center p-6 bg-[#0E1618] border border-white border-opacity-10 w-full max-w-lg mx-4">
          <CornerEdge position="left-top" />
          <CornerEdge position="right-top" />
          <CornerEdge position="left-bottom" />
          <CornerEdge position="right-bottom" />
          
          <SuccessIcon />
          
          <div className="flex flex-col gap-1.5 items-center">
            <h1 className="text-2xl text-center text-white">
              PURCHASE SUCCESSFUL
            </h1>
            <p className="text-lg text-center text-white opacity-50">
              Thank you for shopping with Vertex
            </p>
          </div>
          
          <OrderIdBox orderId={orderId} />
          
          <button
            onClick={onClose}
            className="relative w-[157px] h-[51px]"
          >
            <div className="absolute inset-0 bg-[#0CE77E] bg-opacity-25" />
            <div className="absolute inset-[1px] border border-white border-opacity-5" />
            <span className="absolute inset-0 flex items-center justify-center font-mono text-[17.85px] font-medium text-[#0CE77E]">
              CLOSE
            </span>
            <CornerEdge position="left-top" />
            <CornerEdge position="right-top" />
            <CornerEdge position="left-bottom" />
            <CornerEdge position="right-bottom" />
          </button>
        </div>
      </div>
    );
  }

  // Show payment form
  return (
    <div className="fixed inset-0 z-50 flex items-center justify-center bg-black/80">
      <div className="relative flex flex-col gap-5 p-6 bg-[#0E1618] border border-white border-opacity-10 w-full max-w-lg mx-4">
        {/* Corner decoration elements */}
        <CornerEdge position="left-top" />
        <CornerEdge position="right-top" />
        <CornerEdge position="left-bottom" />
        <CornerEdge position="right-bottom" />
        
        {/* Header */}
        <div className="flex flex-col gap-1">
          <h2 className="text-sm font-medium text-white text-opacity-50">
            Selected configuration
          </h2>
          <h1 className="text-xl font-medium text-[#0CE77E]">
            {gpu.title}
          </h1>
        </div>
        
        {/* Price Display */}
        <div className="relative border border-white border-opacity-10 bg-[#0CE77E]/10">
          <CornerEdge position="left-top" />
          <CornerEdge position="right-top" />
          <CornerEdge position="left-bottom" />
          <CornerEdge position="right-bottom" />
          
          <div className="flex justify-between items-center p-3 w-full">
            <span className="text-base font-medium text-white">Total Price</span>
            <div className="flex gap-3 items-center">
              <span className="text-base font-bold text-[#0CE77E]">${displayPrice}</span>
              <span className="text-base text-[#0CE77E]">(~{currentTokenAmount} {selectedToken})</span>
            </div>
          </div>
        </div>
        
        {/* Email Input */}
        {!user?.email?.address && (
          <div className="relative">
            <span className="block mb-1 text-sm font-medium text-white">YOUR EMAIL ADDRESS</span>
            <div className="relative border border-white border-opacity-10 bg-[#0CE77E]/10">
              <CornerEdge position="left-top" />
              <CornerEdge position="right-top" />
              <CornerEdge position="left-bottom" />
              <CornerEdge position="right-bottom" />
              
              <input
                type="email"
                placeholder="ENTER YOUR EMAIL"
                value={emailInput}
                onChange={(e) => setEmailInput(e.target.value)}
                onBlur={() => setEmailTouched(true)}
                className="w-full p-3 bg-transparent text-[#0CE77E] placeholder-[#0CE77E]/50 focus:outline-none text-base"
              />
            </div>
            {emailTouched && emailInput && !isValidEmail(emailInput) && (
              <p className="mt-1 text-xs text-red-400">Please enter a valid email address.</p>
            )}
          </div>
        )}
        
        {/* Token Selection */}
        <div className="relative">
          <span className="block mb-1 text-sm font-medium text-white">SELECT PAYMENT TOKEN</span>
          <div className="relative border border-white border-opacity-10 bg-[#0CE77E]/10">
            <CornerEdge position="left-top" />
            <CornerEdge position="right-top" />
            <CornerEdge position="left-bottom" />
            <CornerEdge position="right-bottom" />
            
            <select
              value={selectedToken}
              onChange={(e) => setSelectedToken(e.target.value as 'SOL' | 'USDC' | 'VERTEX')}
              className="w-full p-3 bg-transparent text-[#0CE77E] focus:outline-none text-base cursor-pointer"
            >
              <option value="SOL" className="bg-[#0E1618] text-[#0CE77E]">SOL</option>
              <option value="USDC" className="bg-[#0E1618] text-[#0CE77E]">USDC</option>
              <option value="VERTEX" className="bg-[#0E1618] text-[#0CE77E]">{customTokenName}</option>
            </select>
          </div>
        </div>
        
        {/* Error and Success Messages */}
        {errorMsg && (
          <div className="p-2 text-sm text-red-400 border border-red-400 bg-red-400/10">
            {errorMsg}
          </div>
        )}
        
        {successMsg && (
          <div className="p-2 text-sm text-[#0CE77E] border border-[#0CE77E] bg-[#0CE77E]/10">
            {successMsg}
          </div>
        )}
        
        {/* Action Buttons */}
        <div className="flex justify-between gap-3 mt-2">
          {/* Confirm Button */}
          <button
            onClick={handlePayment}
            disabled={loading || (!user?.email?.address && (!emailInput || !isValidEmail(emailInput)))}
            className="relative flex-1 py-3 bg-[#004d33] border border-[#0CE77E]/30 text-[#0CE77E] text-sm font-medium disabled:opacity-50 transition-all hover:bg-[#006644] hover:border-[#0CE77E]/50 hover:shadow-[0_0_12px_rgba(12,231,126,0.3)]"
          >
            <CornerEdge position="left-top" />
            <CornerEdge position="right-top" />
            <CornerEdge position="left-bottom" />
            <CornerEdge position="right-bottom" />
            {loading ? 'PROCESSING...' : 'CONFIRM PAYMENT'}
          </button>
          
          {/* Cancel Button */}
          <button
            onClick={onClose}
            disabled={loading}
            className="relative flex-1 py-3 bg-[#333333] border border-white/30 text-white text-sm font-medium disabled:opacity-50 transition-all hover:bg-[#444444] hover:border-white/50 hover:shadow-[0_0_12px_rgba(255,255,255,0.2)]"
          >
            <CornerEdge position="left-top" />
            <CornerEdge position="right-top" />
            <CornerEdge position="left-bottom" />
            <CornerEdge position="right-bottom" />
            CANCEL
          </button>
        </div>
      </div>
    </div>
  );
};

export default GpuPaymentModal;